@@ -51,7 +51,7 @@ def main():
     elif 'VIRTUAL_ENV' not in os.environ and not args.noninteractive:
         print("WARNING: You are not inside a Python Virtual Environment, using one is strongly recommended")
         yn = None
-        while yn.strip().lower() not in ('y','yes','n','no'):
+        while yn is None or yn.strip().lower() not in ('y','yes','n','no'):
             yn = input("Do you want us to create one for you? (assuming virtualenv is installed) [yn]").strip()
             createvenv = yn.strip().lower() in ("y","yes")
 
@@ -276,7 +276,7 @@ processes = 2
 threads = 2
 #enable this for nginx:
 #manage-script-name = yes
-""".format(sourcedir=sourcedir, rootdir=rootdir,sysid=args.sysid, uwsgiplugin=uwsgiplugin,pythonversion=args.pythonversion, uwsgiport=args.uwsgiport, virtual_env=os.environ['VIRTUAL_ENV']))
+""".format(sourcedir=sourcedir, rootdir=rootdir,sysid=args.sysid, uwsgiplugin=uwsgiplugin,pythonversion=args.pythonversion, uwsgiport=args.uwsgiport))
     if virtualenv:
         with io.open(os.path.join(rootdir,args.sysid + '.' + hostname + '.ini'),'a',encoding='utf-8') as f:
             f.write("virtualenv = " + virtualenv + "\n")
